@@ -3,38 +3,38 @@
 #' @importFrom grDevices "colorRampPalette"
 #' @keywords internal
 gen_gray_bars = function(summ_dt, number_rows, color_bar_data, label_column, min_label_width) {
-  gray_bar_data = summ_dt[order(-summ_dt[['max_rel_val']]),][-c(1:number_rows),]
+  gray_bar_data = summ_dt[order(-summ_dt[["max_rel_val"]]), ][-c(1:number_rows), ]
 
   # calc row height based on num rows
-  bar_h = 1/number_rows
+  bar_h = 1 / number_rows
   #calc y vals for bar heights
   row_y_list = lapply(1:number_rows, function(i) {
-    list(y0 = 1-bar_h*(i-1), y1 = 1-bar_h*i)
+    list(y0 = 1 - bar_h * (i - 1), y1 = 1 - bar_h * i)
   })
 
   #initalize storage
-  gray_bar_list = vector('list', nrow(gray_bar_data))
-  gray_ann_list = vector('list', nrow(gray_bar_data))
-  gray_hover_point_list = vector('list', nrow(gray_bar_data))
+  gray_bar_list = vector("list", nrow(gray_bar_data))
+  gray_ann_list = vector("list", nrow(gray_bar_data))
+  gray_hover_point_list = vector("list", nrow(gray_bar_data))
 
   #get max x level for each bar level
   row_sums = color_bar_data$max_rel_val
   #gen gray ramp function
-  gray_gen = colorRampPalette(c("#E8E8E8","#cccccc"))
+  gray_gen = colorRampPalette(c("#E8E8E8", "#cccccc"))
   #gen gray ramp
   grays = gray_gen(105)
   low_grays = grays[1:50]
   hi_grays  = grays[56:105]
-  last_gray_vec = sample(c(low_grays, hi_grays), number_rows, replace=TRUE)
+  last_gray_vec = sample(c(low_grays, hi_grays), number_rows, replace = TRUE)
   for (i in 1:nrow(gray_bar_data)) {
-    row = gray_bar_data[i,]
+    row = gray_bar_data[i, ]
 
     #calc which row to put block in based on min x value after added this block
-    x_val = as.numeric(row[['max_rel_val']])
+    x_val = as.numeric(row[["max_rel_val"]])
     home_row = which.min(row_sums + x_val)
     x0 = row_sums[[home_row]]
     x1 = row_sums[[home_row]] + x_val
-    row_sums[[home_row]] <- x1
+    row_sums[[home_row]] = x1
 
     if (i == 1) {
       # random gray
@@ -51,7 +51,7 @@ gen_gray_bars = function(summ_dt, number_rows, color_bar_data, label_column, min
     out_bar = list(
       type = "rect",
       fillcolor = color_i,
-      line = list(color = color_i, width=.1),
+      line = list(color = color_i, width = .1),
       x0 = x0,
       x1 = x1,
       xref = "x",
@@ -60,13 +60,13 @@ gen_gray_bars = function(summ_dt, number_rows, color_bar_data, label_column, min
     )
 
     #calc center x and y point for current bar
-    x = x0 + x_val/2
-    y = row_y_list[[home_row]]$y0 - (row_y_list[[home_row]]$y0 - row_y_list[[home_row]]$y1)/2
+    x = x0 + x_val / 2
+    y = row_y_list[[home_row]]$y0 - (row_y_list[[home_row]]$y0 - row_y_list[[home_row]]$y1) / 2
     out_ann = list(
       x = x,
       y = y,
-      xref = 'x',
-      yref = 'y',
+      xref = "x",
+      yref = "y",
       #set label
       text = row[[label_column]],
       showarrow = FALSE
@@ -75,9 +75,9 @@ gen_gray_bars = function(summ_dt, number_rows, color_bar_data, label_column, min
     #put point at center of shape for hover info
     hover_point = data.table::data.table(
       name = row[[label_column]],
-      x = seq(x0, x0+x_val, length.out = 10),
+      x = seq(x0, x0 + x_val, length.out = 10),
       y = y,
-      size = x1-x0
+      size = x1 - x0
     )
 
     #dont show annotation if smaller than threshold
